@@ -180,26 +180,6 @@ class TestGenericSwitchDriver(unittest.TestCase):
         self.assertIn('Failed to delete network', m_log.error.call_args[0][0])
         self.assertNotIn('has been deleted', m_log.info.call_args[0][0])
 
-    @mock.patch('networking_generic_switch.generic_switch_mech.LOG')
-    def test_delete_network_postcommit_no_network_id(self, m_log, m_list):
-        driver = gsm.GenericSwitchDriver()
-        driver.initialize()
-        mock_context = mock.create_autospec(driver_context.NetworkContext)
-        mock_context.current = {'id': 22,
-                                'provider:network_type': 'vlan',
-                                'provider:segmentation_id': 22,
-                                'provider:physical_network': 'physnet1'}
-        self.switch_mock.del_network.side_effect = TypeError
-
-        driver.delete_network_postcommit(mock_context)
-        self.assertEqual([mock.call(22, 22), mock.call(22)],
-                         self.switch_mock.del_network.call_args_list)
-        self.assertEqual(m_log.warn.call_count, 1)
-
-        # Ensure the warning is only logged once.
-        driver.delete_network_postcommit(mock_context)
-        self.assertEqual(m_log.warn.call_count, 1)
-
     def test_delete_port_postcommit(self, m_list):
         driver = gsm.GenericSwitchDriver()
         driver.initialize()
